struct gl_MaterialParameters {
	vec4 emission;
	vec4 ambient;
	vec4 diffuse;
	vec4 specular;
	float shininess;
};

uniform gl_MaterialParameters gl_FrontMaterial;

uniform sampler2D baseMap;

varying vec2 Texcoord;
varying vec3 ViewDirection;
varying vec3 LightDirection;
varying vec3 Normal;

uniform int isTextured;

void main( void )
{
   vec3  fvLightDirection = normalize( LightDirection );
   vec3  fvNormal         = normalize( Normal );
   float fNDotL           = dot( fvNormal, fvLightDirection ); 
   
   vec3  fvReflection     = normalize( ( ( 2.0 * fvNormal ) * fNDotL ) - fvLightDirection ); 
   vec3  fvViewDirection  = normalize( ViewDirection );
   float fRDotV           = max( 0.0, dot( fvReflection, fvViewDirection ) );
   
   vec4 fvBaseColor;
   
   if (isTextured == 0) fvBaseColor = (1.0, 1.0, 1.0, 1.0);
   else fvBaseColor      = texture2D( baseMap, Texcoord );
   
   vec4  fvTotalAmbient   = gl_FrontMaterial.ambient * fvBaseColor; 
   vec4  fvTotalDiffuse   = gl_FrontMaterial.diffuse * fNDotL * fvBaseColor; 
   vec4  fvTotalSpecular  = gl_FrontMaterial.specular * ( pow( fRDotV, gl_FrontMaterial.shininess + 1.0 ) );
  
   gl_FragColor = ( fvTotalAmbient * gl_LightSource[0].ambient + fvTotalDiffuse * gl_LightSource[0].diffuse + fvTotalSpecular * gl_LightSource[0].specular );
       
}